pub trait DefinesInternalPunctuation {
const INTERNAL_PUNCTUATION: &'static Set<char> = _;
// Provided method
fn is_internal_punctuation(c: &char) -> bool { ... }
}Expand description
Defines a set of punctuation that can occur within a word.
Provided Associated Constants
Sourceconst INTERNAL_PUNCTUATION: &'static Set<char> = _
const INTERNAL_PUNCTUATION: &'static Set<char> = _
The set of legal punctuation characters that can occur within a word.
Provided Methods
Sourcefn is_internal_punctuation(c: &char) -> bool
fn is_internal_punctuation(c: &char) -> bool
Checks if a character is a legal punctuation character that can occur within a word.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.